@@ -225,12 +225,16 @@ class DictToXml(object):
                         suite_id[pre_path] = pid
         return suite_id
 
+    def enable_update(self):
+        self.update = 1
+
     def read_req_id_dict(self, req_xml_path, update=''):
         self.id_dict = read_xml.read_req_id_xml(req_xml_path)
+        #update参数，给xml_update用的
         if update == 'update':
             self.only_reqs_id_dict = read_xml.read_only_reqs_id_xml(req_xml_path)
             self.suite_id = self.get_suite_id(self.id_dict)
-            self.update = 1
+        #    self.update = 1
         #print(self.id_dict)
     
     def get_case_xml(self, in_dict, node = '', api = False, argv = '',\
@@ -261,7 +265,9 @@ class DictToXml(object):
                     sm = ET.SubElement(tc, self.case_tag['sm'])
                     msg = case[self.case_tag['sm']]
                     if api == True:
-                        case_argv = argv + "<li>" + case['title'] + "</li>"
+                        final_argv = case['title'].split("~")[-1]
+                        #case_argv = argv + "<li>" + case['title'] + "</li>"
+                        case_argv = argv + "<li>" + final_argv + "</li>"
                         msg = sms + msg + "\n\n参数设置: \n" + "<ul>" + case_argv + "</ul>"
                     self.cdata(sm, msg)
                 if case[self.case_tag['ip']] != '':
@@ -293,11 +299,13 @@ class DictToXml(object):
                     for custom_field in  case[self.case_tag['cf']]:
                         cf = ET.SubElement(cfs, self.case_tag['cf'])
                         for k,v in custom_field.items():
+                            if k == "绑定":
+                                pass
                             nm = ET.SubElement(cf, self.case_tag['nm'])
                             self.cdata(nm, k)
                             val = ET.SubElement(cf, self.case_tag['val'])
                             self.cdata(val, v)
-                if case['reqband'] != '':
+                if 'reqband' in case and case['reqband'] != '' and self.update == 0:
                     #绑定需求
                     reqs = ET.SubElement(tc, self.req_tag['reqs'])
                     req = ET.SubElement(reqs, self.req_tag['rq'])
@@ -317,6 +325,15 @@ class DictToXml(object):
                         self.cdata(did, doc_id)
                         rqt = ET.SubElement(req, self.req_tag['rqt'])
                         self.cdata(rqt, k.split('/')[-1])
+                if 'old_band' in case and self.update == 1:
+                    reqs = ET.SubElement(tc, self.req_tag['reqs'])
+                    for old_req in  case["old_band"]:
+                        req = ET.SubElement(reqs, self.req_tag['rq'])
+                        for k,v in old_req.items():
+                            did = ET.SubElement(req, self.req_tag['did'])
+                            self.cdata(did, k)
+                            rqt = ET.SubElement(req, self.req_tag['rqt'])
+                            self.cdata(rqt, v)
 
         if "suites" in in_dict.keys() and in_dict['suites'] != []:
             #递归，遍历嵌套的测试集
