@@ -69,7 +69,7 @@ def run(xmind_file_list, xmind_type, is_api, xmind_msg, xd, dx, output_dir, \
         id_count = 1
         if auto_id:
             for xmind_file in xmind_file_list:
-                try :
+                #try :
                     root_dict, req_dict = xd.start(xmind_file)
                     if need_case:
                         #print(root_dict)
@@ -81,9 +81,9 @@ def run(xmind_file_list, xmind_type, is_api, xmind_msg, xd, dx, output_dir, \
                         if req_dict['cases'] != []:
                             dx.get_case_req_xml(req_dict['cases'], req_total, auto_id, root_id)
                     print("SUCCESS \t" + xmind_file)
-                except Exception as e:
-                    print(e)
-                    print('\033[1;31mFAILED \t%s\033[m'%xmind_file)
+                #except Exception as e:
+                #    print(e)
+                #    print('\033[1;31mFAILED \t%s\033[m'%xmind_file)
             if need_case:
                 save_xml(dx, out, xml_path)
             if need_req:
@@ -114,6 +114,7 @@ def run(xmind_file_list, xmind_type, is_api, xmind_msg, xd, dx, output_dir, \
                 for xmind_file in xmind_file_list:
                     try:
                         root_dict, req_dict = xd.start(xmind_file)
+                        print(root_dict['suites'][0])
                         dx.get_case_xml(root_dict['suites'][0], out, api = is_api, \
                                 argv = '', auto_id = False, name = name)
                         print("case_SUCCESS \t" + xmind_file)
@@ -134,7 +135,7 @@ def main():
             help='xmind file directory')
     group.add_argument('-f', '--file', dest='file', metavar='File', nargs="+",
             help='xmind file')
-    parser.add_argument('-t', '--type', dest='file_type', choices=['req','case','chipreq'], default='case',
+    parser.add_argument('-t', '--type', dest='file_type', choices=['req','case','chipreq', 'chipcase'], default='case',
             required=True,
             help='xmind file type')
     parser.add_argument('-i', '--id', dest='root_id', metavar='ID', nargs=1,
