@@ -16,7 +16,12 @@ tag = {
     "ip":"importance",
     "et":"execution_type",
     "nm":"name",
-    "val":"value"
+    "val":"value",
+    "reqs":"requirements",
+    "req":"requirement",
+    "rst":"req_spec_title",
+    "did":"doc_id",
+    "rqt":"title"
 }
 
 def get_suite(name, suite_detail = ''):
@@ -40,7 +45,7 @@ def clean_data(msg):
     return msg.replace('<p>','').replace('</p>','').replace('<br />','\n').strip(" \n")
     #return msg
 
-def get_case(elem):
+def get_case(elem, band_msg):
     case = {
             'title':'',
             'summary':'',
@@ -72,9 +77,14 @@ def get_case(elem):
                 case['custom_field'].append({custom.findtext(tag['nm']): custom.findtext(tag['val'])})
         if case['custom_field'] == []:
             case['custom_field'] = ''
+    if band_msg:
+        if elem.find(tag['reqs']) != None:
+            case['old_band'] = []
+            for req in elem.findall(tag['reqs'] + "/" + tag['req']):
+                case['old_band'].append({req.findtext(tag['did']):req.findtext(tag['rqt'])})
     return case
 
-def get_case_dict(elem, out_dict):
+def get_case_dict(elem, out_dict, band_msg):
     if elem.tag == "testsuite":
         suite_name = elem.attrib['name']
         if elem.find(tag['dt']) != None:
@@ -88,9 +98,9 @@ def get_case_dict(elem, out_dict):
             if child.tag == 'details':
                 pass
             elif child.tag == 'testcase':
-                out_dict['cases'].append(get_case(child))
+                out_dict['cases'].append(get_case(child, band_msg))
             elif child.tag == 'testsuite':
-                get_case_dict(child, out_dict)
+                get_case_dict(child, out_dict, band_msg)
 
 def read_req_id(elem):
     if elem.find("docid") != None:
@@ -117,11 +127,11 @@ def get_req_id_dict(elem, pre_name = ''):
             id_dict.update(get_req_id_dict(child, pre_name))
     return id_dict
 
-def read_case_xml(xml_file):
+def read_case_xml(xml_file, band_msg = True):
     tree = ET.ElementTree(file = xml_file)
     root = tree.getroot()
     out_dict = get_suite("最外层")
-    get_case_dict(root, out_dict)
+    get_case_dict(root, out_dict, band_msg)
     return out_dict['suites'][0]
 
 def get_req(elem):
@@ -240,8 +250,14 @@ def get_root_id(xml_file):
             root_id = child.attrib["doc_id"]
             return  root_id
 
+def get_root_name(xml_file):
+    tree = ET.ElementTree(file = xml_file)
+    root = tree.getroot()
+    return root.attrib['name']
+
 if __name__ == "__main__":
-    #print(read_case_xml('./demo.xml'))
+    #print(read_case_xml('./ddd.xml', False))
+    #print(get_root_name("./ddd.xml"))
     #print(read_req_id_xml('./case_req.xml'))
-    #read_req_id_xml('./backup.xml')
-    print(read_req_xml('./chip_req.xml'))
+    print(read_req_id_xml('./rrr.xml'))
+    #print(read_req_xml('./chip_req.xml'))
